@@ -19,7 +19,7 @@ INTERMEDIATE_SUBCLASSES = {}
 
 class Database:
 
-    def __init__(self, name=None):
+    def __init__(self, name='*unnamed database*'):
         self.name = name
         self._reagents = {}
 
@@ -95,8 +95,12 @@ class Reagent:
         attrs = list(self._attrs.items())
         if isinstance(self, IntermediateMixin):
             attrs.insert(0, ('step', self.step))
-        attr_strs = ', '.join(f'{k}={v!r}' for k, v in attrs)
-        return f'{self.__class__.__qualname__}({attr_strs})'
+
+        attr_strs = [f'{k}={v!r}' for k, v in attrs]
+        if self._tag:
+            attr_strs.insert(0, repr(str(self._tag)))
+
+        return f'{self.__class__.__qualname__}({", ".join(attr_strs)})'
 
     def check(self):
         pass
@@ -181,15 +185,18 @@ class Reagent:
         return self._attrs.get('desc', '')
 
     def get_dependencies(self):
-        return set(self.synthesis_maker.dependencies)
+        try:
+            return frozenset(self.synthesis_maker.dependencies)
+        except QueryError:
+            return frozenset()
 
-    def get_pending(self):
-        pending = self._attrs.get('pending', False)
+    def get_ready(self):
+        ready = self._attrs.get('ready', True)
 
-        if callable(pending):
-            pending = pending()
+        if callable(ready):
+            ready = ready()
 
-        return pending
+        return ready
 
     def get_maker_attr(self, attr, default=NO_DEFAULT):
         try:
